#!/bin/bash

actzTrace "XSETNETT: editFirewallChainByDest $*"

op=$1
sourceAddr=$2
sourceAddrMask=$3
destAddr=$4
destAddrMask=$5
protocol=$6
port=$7
isIPv6=$8

if [ "$isIPv6" = "true" ]; then
    if ! lsmod | grep -q "ipv6"; then
        actzTrace "XSETNETF: editFirewallChainByDest: no IPv6 support."
        exit 0
    fi

    if [ -x /sbin/ip6tables ]; then
        iptables=/sbin/ip6tables
    elif [ -x /usr/sbin/ip6tables ]; then
        iptables=/usr/sbin/ip6tables
    else
        actzTrace "XSETNETF: editFirewallChainByDest: No ip6tables executable found."
        exit 0
    fi
else
    if [ -x /sbin/iptables ]; then
        iptables=/sbin/iptables
    elif [ -x /usr/sbin/iptables ]; then
        iptables=/usr/sbin/iptables
    else
        actzTrace "XSETNETF: editFirewallChainByDest: No iptables executable found."
        exit 0
    fi
fi

# Check to see if the chain has been created yet
if $iptables -L -n | grep "HMC-INPUT-BY-DEST"; then
    actzTrace "XSETNETF: found the chain.. no need to created it"
else
    actzTrace "XSETNETF: creating HMC-INPUT-BY-DEST chain"
    $iptables --new HMC-INPUT-BY-DEST && \
    $iptables --insert INPUT --jump HMC-INPUT-BY-DEST
    rc=$?
    if [ "$rc" != "0" ]; then
        actzTrace "XSETNETF: error creating chain: $rc"
    fi
fi

if [ "$protocol" = "icmp" ]; then
    cmd="$iptables $op HMC-INPUT-BY-DEST --source $sourceAddr/$sourceAddrMask --destination $destAddr/$destAddrMask --protocol icmp --icmp-type $port --jump ACCEPT --verbose"
    actzTrace "XSETNETF: executing cmd: '$cmd'"
    $cmd
    rc=$?
elif echo $port | grep ","; then
    ports=$(echo $port | sed -e "s/,/ /g")
    for port in $ports; do
        cmd="$iptables $op HMC-INPUT-BY-DEST --source $sourceAddr/$sourceAddrMask --destination $destAddr/$destAddrMask --protocol $protocol --destination-port $port --jump ACCEPT --verbose"
        actzTrace "XSETNETF: executing cmd: '$cmd'"
        $cmd
        rc=$?
        if [ "$rc" != "0" ]; then
            exit $rc
        fi
    done
else
    cmd="$iptables $op HMC-INPUT-BY-DEST --source $sourceAddr/$sourceAddrMask --destination $destAddr/$destAddrMask --protocol $protocol --destination-port $port --jump ACCEPT --verbose"
    actzTrace "XSETNETF: executing cmd: '$cmd'"
    $cmd
    rc=$?
fi

actzTrace "XSETNETF: <- editFirewallChainByDest: rc=$rc"

exit $rc
